BootTimeAccessor

Trait BootTimeAccessor 

pub trait BootTimeAccessor {
    // Required methods
    fn set_boot_timestamp(&mut self, _boot_ts_nanos: Timestamp);
    fn get_boot_timestamp(&self) -> Timestamp;
}

Required Methods

fn set_boot_timestamp(&mut self, _boot_ts_nanos: Timestamp)

Sets the boot timestamp in nanoseconds since the Unix epoch.

fn get_boot_timestamp(&self) -> Timestamp

Returns the boot timestamp in nanoseconds since the Unix epoch.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<W> BootTimeAccessor for DefaultLogFormatter<W>
where W: Write + ToolIO<OutputItem = LogEntry>,